=============================
django-admintheme v |version|
=============================

Django Admin Theme is a CSS-only skin for the Django's Admin app. This allows
projects that make customizations to the standard admin templates to work
without modification.

Goals
=====

* Update the Django admin interface *without* template modifications.

* Use SASS_ stylesheets with the Compass_ framework to provide flexibility (and variables).

* Provide a configuration file to make customizing the theme easy.

* Provide static HTML files for each admin screen with all options to make styling easier

.. _Compass: http://compass-style.org/

.. _SASS: http://sass-lang.com/


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   testing
   reference/index
